==> ackee-frontend-toolkit-0.8.2.tgz: package/es/HOC/makeDropzone.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Receiver } from 'react-file-uploader';

export var FS = {
    failed: -1,
    pending: 0,
    uploading: 1,
    uploaded: 2
};

export default (function (DropzoneGraphic) {
    var _class, _temp;

    return _temp = _class = function (_React$Component) {
        _inherits(Dropzone, _React$Component);

        function Dropzone(props) {
            _classCallCheck(this, Dropzone);

            var _this = _possibleConstructorReturn(this, (Dropzone.__proto__ || Object.getPrototypeOf(Dropzone)).call(this, props));

            _this.onDrop = function (e, file) {
                _this.setState({
                    state: FS.uploading,
                    mouseOver: false
                });

                if (typeof _this.props.onDrop === 'function') {
                    _this.props.onDrop(file);

                    _this.setState({
                        state: file ? FS.uploaded : FS.failed
                    });
                }
            };

            _this.handleDragOver = function () {
                if (_this.state.state === FS.uploading) return;
                if (!_this.state.mouseOver) {
                    _this.setState({
                        mouseOver: true
                    });
                }
            };

            _this.handleDragLeave = function () {
                if (_this.state.state === FS.uploading) return;
                _this.setState({
                    mouseOver: false
                });
            };

            _this.handleClick = function () {
                _this.imageInput.click();
            };

            _this.state = {
                state: null,
                mouseOver: false
            };
            _this.imageInput = null;

            window.DragEvent = 'dummy';
            return _this;
        }

        _createClass(Dropzone, [{
            key: 'render',
            value: function render() {
                var _this2 = this;

                var _props = this.props,
                    onDrop = _props.onDrop,
                    wrapperId = _props.wrapperId,
                    restProps = _objectWithoutProperties(_props, ['onDrop', 'wrapperId']);

                return React.createElement(
                    'div',
                    { style: { display: 'flex', flexWrap: 'wrap', justifyContent: 'space-between', alignItems: 'center' } },
                    React.createElement(
                        'div',
                        { style: { flex: '1' } },
                        React.createElement(
                            Receiver,
                            {
                                key: 'logo',
                                wrapperId: wrapperId,
                                onFileDrop: function onFileDrop(e, file) {
                                    return _this2.onDrop(e, file);
                                },
                                isOpen: true,
                                onDragEnter: function onDragEnter() {},
                                onDragOver: this.handleDragOver,
                                onDragLeave: this.handleDragLeave
                            },
                            React.createElement(
                                'div',
                                { role: 'button', tabIndex: '-1', onClick: this.handleClick },
                                React.createElement(DropzoneGraphic, _extends({
                                    isMouseOver: this.state.mouseOver,
                                    uploadState: this.state.state
                                }, restProps))
                            )
                        ),
                        React.createElement(
                            'div',
                            { style: { visibility: 'hidden' } },
                            React.createElement('input', { ref: function ref(r) {
                                    return _this2.imageInput = r;
                                }, type: 'file', name: 'photo', onChange: function onChange(e) {
                                    return _this2.onDrop(e, e.target.files);
                                } })
                        )
                    )
                );
            }
        }]);

        return Dropzone;
    }(React.Component), _class.propTypes = {
        onDrop: PropTypes.func.isRequired,
        wrapperId: PropTypes.string
    }, _class.defaultProps = {
        wrapperId: null
    }, _temp;
});

==> ackee-frontend-toolkit-0.16.1.tgz: package/es/HOC/makeDropzone.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import { Receiver } from 'react-file-uploader';

export var FS = {
    failed: -1,
    pending: 0,
    uploading: 1,
    uploaded: 2
};

export default (function (DropzoneGraphic) {
    var _class, _temp;

    return _temp = _class = function (_React$Component) {
        _inherits(Dropzone, _React$Component);

        _createClass(Dropzone, null, [{
            key: 'generateInputKey',
            value: function generateInputKey() {
                return Math.random().toString(36);
            }
        }]);

        function Dropzone(props) {
            _classCallCheck(this, Dropzone);

            var _this = _possibleConstructorReturn(this, (Dropzone.__proto__ || Object.getPrototypeOf(Dropzone)).call(this, props));

            _this.onDrop = function (files) {
                var _this$props = _this.props,
                    filesValidation = _this$props.filesValidation,
                    onDrop = _this$props.onDrop;


                files = filesValidation(files);

                _this.setState({
                    state: FS.uploading,
                    mouseOver: false
                });

                if (typeof onDrop === 'function') {
                    onDrop(files);

                    _this.setState({
                        state: files ? FS.uploaded : FS.failed
                    });
                }
            };

            _this.handleDragOver = function () {
                if (_this.state.state === FS.uploading) return;
                if (!_this.state.mouseOver) {
                    _this.setState({
                        mouseOver: true
                    });
                }
            };

            _this.handleDragLeave = function () {
                if (_this.state.state === FS.uploading) return;
                _this.setState({
                    mouseOver: false
                });
            };

            _this.handleClick = function () {
                _this.imageInput.click();
            };

            _this.resetInput = function () {
                _this.setState({
                    state: null,
                    mouseOver: false,
                    inputKey: Dropzone.generateInputKey()
                });
            };

            _this.state = {
                state: null,
                mouseOver: false,
                inputKey: Dropzone.generateInputKey()
            };
            _this.imageInput = null;

            window.DragEvent = 'dummy';
            return _this;
        }

        _createClass(Dropzone, [{
            key: 'render',
            value: function render() {
                var _this2 = this;

                var _props = this.props,
                    onDrop = _props.onDrop,
                    wrapperId = _props.wrapperId,
                    input = _props.input,
                    restProps = _objectWithoutProperties(_props, ['onDrop', 'wrapperId', 'input']);

                return React.createElement(
                    'div',
                    {
                        style: {
                            display: 'flex',
                            flexWrap: 'wrap',
                            justifyContent: 'space-between',
                            alignItems: 'center'
                        }
                    },
                    React.createElement(
                        'div',
                        { style: { flex: '1' } },
                        React.createElement(
                            Receiver,
                            {
                                key: 'logo',
                                wrapperId: wrapperId,
                                onFileDrop: function onFileDrop(e, files) {
                                    return _this2.onDrop(files.map(function (f) {
                                        return f.data;
                                    }));
                                },
                                isOpen: true,
                                onDragEnter: function onDragEnter() {},
                                onDragOver: this.handleDragOver,
                                onDragLeave: this.handleDragLeave
                            },
                            React.createElement(
                                'div',
                                {
                                    role: 'button',
                                    tabIndex: '-1',
                                    onClick: this.handleClick
                                },
                                React.createElement(DropzoneGraphic, _extends({
                                    isMouseOver: this.state.mouseOver,
                                    uploadState: this.state.state
                                }, restProps))
                            )
                        ),
                        React.createElement(
                            'div',
                            { style: { visibility: 'hidden' } },
                            React.createElement('input', _extends({}, input, {
                                ref: function ref(_ref) {
                                    return _this2.imageInput = _ref;
                                },
                                type: 'file',
                                name: 'photo',
                                onChange: function onChange(e) {
                                    return _this2.onDrop(Array.from(e.target.files));
                                }
                            }))
                        )
                    )
                );
            }
        }]);

        return Dropzone;
    }(React.Component), _class.propTypes = {
        onDrop: PropTypes.func.isRequired,
        wrapperId: PropTypes.string,
        input: PropTypes.shape({
            accept: PropTypes.string,
            multiple: PropTypes.bool
        }),
        filesValidation: PropTypes.func
    }, _class.defaultProps = {
        wrapperId: null,
        input: {
            accept: '',
            multiple: false
        },
        filesValidation: function filesValidation(files) {
            return files;
        }
    }, _temp;
});
